@@ -1,4 +1,4 @@
-#!/usr/bin/python -Es
+#!/usr/bin/python3 -Es
 #
 # polgengui.py - GUI for SELinux Config tool in system-config-selinux
 #
@@ -63,16 +63,16 @@ def get_all_modules():
 ##
 ## I18N
 ##
-PROGNAME = "policycoreutils"
+PROGNAME = "selinux-gui"
 try:
     import gettext
     kwargs = {}
     if sys.version_info < (3,):
         kwargs['unicode'] = True
-    gettext.install(PROGNAME,
+    t = gettext.translation(PROGNAME,
                     localedir="/usr/share/locale",
-                    codeset='utf-8',
                     **kwargs)
+    _ = t.gettext
 except:
     try:
         import builtins
@@ -769,7 +769,7 @@ class childWindow:
             self.syslog_checkbutton.set_active(policy.use_syslog)
 
     def stand_alone(self):
-        desktopName = _("Configue SELinux")
+        desktopName = _("Configure SELinux")
 
         self.setupScreen()
         self.mainWindow.connect("destroy", self.quit)
